json

package module
v0.0.0-...-e7cd1cc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2022 License: Unlicense Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type JSONSource

type JSONSource struct {
	// contains filtered or unexported fields
}

DO NOT CREATE INSTANCES MANUALLY, THIS IS ONLY PUBLIC IN ORDER FOR GODOC TO RENDER AVAILABLE FUNCTIONS.

func Source

func Source(path string) *JSONSource

Source creates a source for a JSON file.

func (*JSONSource) KeyTag

func (s *JSONSource) KeyTag() string

KeyTag implements Source.Key.

func (*JSONSource) Must

func (s *JSONSource) Must() *JSONSource

Must indicates that this Source will return an error during parsing if no parsable data can be found.

func (*JSONSource) Parse

func (s *JSONSource) Parse(configurationStruct any) (bool, error)

Parse implements Source.Parse.

Jump to