Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JSONSource ¶
type JSONSource struct {
// contains filtered or unexported fields
}
DO NOT CREATE INSTANCES MANUALLY, THIS IS ONLY PUBLIC IN ORDER FOR GODOC TO RENDER AVAILABLE FUNCTIONS.
func (*JSONSource) Must ¶
func (s *JSONSource) Must() *JSONSource
Must indicates that this Source will return an error during parsing if no parsable data can be found.
Click to show internal directories.
Click to hide internal directories.